==> vscat-1.0.0.tgz: package/tests/highlighting/sources/json/npm-package/results/output.default-light-plus.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test default-light-plus theme 1`] = `
Object {
  "lines": Array [
    "[48;2;255;255;255m [38;2;35;120;147m 1 │ [39m[38;2;0;0;0m{[39m                                                                         [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 2 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"name\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"test-package\\"[39m[38;2;0;0;0m,[39m                                                 [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 3 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"description\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"Some[39m[38;2;214;214;214m·[39m[38;2;163;21;21museful[39m[38;2;214;214;214m·[39m[38;2;163;21;21mpackage[39m[38;2;214;214;214m·[39m[38;2;163;21;21mto[39m[38;2;214;214;214m·[39m[38;2;163;21;21mdo[39m[38;2;214;214;214m·[39m[38;2;163;21;21msome[39m[38;2;214;214;214m·[39m[38;2;163;21;21museful[39m[38;2;214;214;214m·[39m[38;2;163;21;21mstuff[39m[38;2;214;214;214m·[39m[38;2;163;21;21mwith[39m[38;2;214;214;214m·[39m[38;2;163;21;21madvanc[39m[38;2;163;21;21m…[39m[49m",
    "[48;2;255;255;255m [38;2;35;120;147m 4 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"version\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"1.0.0\\"[39m[38;2;0;0;0m,[39m                                                     [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 5 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"private\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;0;0;255mtrue[39m[38;2;0;0;0m,[39m                                                        [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 6 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"license\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"MIT\\"[39m[38;2;0;0;0m,[39m                                                       [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 7 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"dependencies\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;0;0;0m{[39m                                                       [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 8 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"package-1\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"1.0.0\\"[39m[38;2;0;0;0m,[39m                                                 [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 9 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"package-2\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"2.0.0\\"[39m[38;2;0;0;0m,[39m                                                 [49m",
    "[48;2;255;255;255m [38;2;35;120;147m10 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"package-3\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"3.0.0\\"[39m[38;2;0;0;0m,[39m                                                 [49m",
    "[48;2;255;255;255m [38;2;35;120;147m11 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"package-4\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"4.0.0\\"[39m[38;2;0;0;0m,[39m                                                 [49m",
    "[48;2;255;255;255m [38;2;35;120;147m12 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"package-5\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"5.0.0\\"[39m[38;2;0;0;0m,[39m                                                 [49m",
    "[48;2;255;255;255m [38;2;35;120;147m13 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"package-6\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;255;255;255m [38;2;35;120;147m14 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;0;0;0m}[39m                                                                       [49m",
    "[48;2;255;255;255m [38;2;35;120;147m15 │ [39m[38;2;0;0;0m}[39m                                                                         [49m",
    "[48;2;255;255;255m [38;2;35;120;147m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ ─────── │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  2, 8 │ #0451A5 │ \\"name\\"
 1 │  8, 9 │ ─────── │ :
 1 │ 10,24 │ #A31515 │ \\"test-package\\"
 1 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  2,15 │ #0451A5 │ \\"description\\"
 2 │ 15,16 │ ─────── │ :
 2 │ 17,90 │ #A31515 │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  2,11 │ #0451A5 │ \\"version\\"
 3 │ 11,12 │ ─────── │ :
 3 │ 13,20 │ #A31515 │ \\"1.0.0\\"
 3 │ 20,21 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  2,11 │ #0451A5 │ \\"private\\"
 4 │ 11,12 │ ─────── │ :
 4 │ 13,17 │ #0000FF │ true
 4 │ 17,18 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  2,11 │ #0451A5 │ \\"license\\"
 5 │ 11,12 │ ─────── │ :
 5 │ 13,18 │ #A31515 │ \\"MIT\\"
 5 │ 18,19 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  2,16 │ #0451A5 │ \\"dependencies\\"
 6 │ 16,17 │ ─────── │ :
 6 │ 18,19 │ ─────── │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  4,15 │ #0451A5 │ \\"package-1\\"
 7 │ 15,16 │ ─────── │ :
 7 │ 17,24 │ #A31515 │ \\"1.0.0\\"
 7 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  4,15 │ #0451A5 │ \\"package-2\\"
 8 │ 15,16 │ ─────── │ :
 8 │ 17,24 │ #A31515 │ \\"2.0.0\\"
 8 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  4,15 │ #0451A5 │ \\"package-3\\"
 9 │ 15,16 │ ─────── │ :
 9 │ 17,24 │ #A31515 │ \\"3.0.0\\"
 9 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  4,15 │ #0451A5 │ \\"package-4\\"
10 │ 15,16 │ ─────── │ :
10 │ 17,24 │ #A31515 │ \\"4.0.0\\"
10 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  4,15 │ #0451A5 │ \\"package-5\\"
11 │ 15,16 │ ─────── │ :
11 │ 17,24 │ #A31515 │ \\"5.0.0\\"
11 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  4,15 │ #0451A5 │ \\"package-6\\"
12 │ 15,16 │ ─────── │ :
12 │ 17,24 │ #A31515 │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  2, 3 │ ─────── │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ ─────── │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;

==> vscat-1.0.1.tgz: package/tests/highlighting/sources/json/npm-package/results/output.default-light-plus.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test default-light-plus theme 1`] = `
Object {
  "lines": Array [
    "[48;2;255;255;255m [38;2;35;120;147m 1 │ [39m[38;2;0;0;0m{[39m                                                                         [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 2 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"name\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"test-package\\"[39m[38;2;0;0;0m,[39m                                                 [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 3 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"description\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"Some[39m[38;2;214;214;214m·[39m[38;2;163;21;21museful[39m[38;2;214;214;214m·[39m[38;2;163;21;21mpackage[39m[38;2;214;214;214m·[39m[38;2;163;21;21mto[39m[38;2;214;214;214m·[39m[38;2;163;21;21mdo[39m[38;2;214;214;214m·[39m[38;2;163;21;21msome[39m[38;2;214;214;214m·[39m[38;2;163;21;21museful[39m[38;2;214;214;214m·[39m[38;2;163;21;21mstuff[39m[38;2;214;214;214m·[39m[38;2;163;21;21mwith[39m[38;2;214;214;214m·[39m[38;2;163;21;21madvanc…[39m[49m",
    "[48;2;255;255;255m [38;2;35;120;147m 4 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"version\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"1.0.0\\"[39m[38;2;0;0;0m,[39m                                                     [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 5 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"private\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;0;0;255mtrue[39m[38;2;0;0;0m,[39m                                                        [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 6 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"license\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"MIT\\"[39m[38;2;0;0;0m,[39m                                                       [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 7 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"dependencies\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;0;0;0m{[39m                                                       [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 8 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"package-1\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"1.0.0\\"[39m[38;2;0;0;0m,[39m                                                 [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 9 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"package-2\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"2.0.0\\"[39m[38;2;0;0;0m,[39m                                                 [49m",
    "[48;2;255;255;255m [38;2;35;120;147m10 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"package-3\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"3.0.0\\"[39m[38;2;0;0;0m,[39m                                                 [49m",
    "[48;2;255;255;255m [38;2;35;120;147m11 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"package-4\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"4.0.0\\"[39m[38;2;0;0;0m,[39m                                                 [49m",
    "[48;2;255;255;255m [38;2;35;120;147m12 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"package-5\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"5.0.0\\"[39m[38;2;0;0;0m,[39m                                                 [49m",
    "[48;2;255;255;255m [38;2;35;120;147m13 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;4;81;165m\\"package-6\\"[39m[38;2;0;0;0m:[39m[38;2;214;214;214m·[39m[38;2;163;21;21m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;255;255;255m [38;2;35;120;147m14 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;0;0;0m}[39m                                                                       [49m",
    "[48;2;255;255;255m [38;2;35;120;147m15 │ [39m[38;2;0;0;0m}[39m                                                                         [49m",
    "[48;2;255;255;255m [38;2;35;120;147m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ ─────── │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  2, 8 │ #0451A5 │ \\"name\\"
 1 │  8, 9 │ ─────── │ :
 1 │ 10,24 │ #A31515 │ \\"test-package\\"
 1 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  2,15 │ #0451A5 │ \\"description\\"
 2 │ 15,16 │ ─────── │ :
 2 │ 17,90 │ #A31515 │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  2,11 │ #0451A5 │ \\"version\\"
 3 │ 11,12 │ ─────── │ :
 3 │ 13,20 │ #A31515 │ \\"1.0.0\\"
 3 │ 20,21 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  2,11 │ #0451A5 │ \\"private\\"
 4 │ 11,12 │ ─────── │ :
 4 │ 13,17 │ #0000FF │ true
 4 │ 17,18 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  2,11 │ #0451A5 │ \\"license\\"
 5 │ 11,12 │ ─────── │ :
 5 │ 13,18 │ #A31515 │ \\"MIT\\"
 5 │ 18,19 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  2,16 │ #0451A5 │ \\"dependencies\\"
 6 │ 16,17 │ ─────── │ :
 6 │ 18,19 │ ─────── │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  4,15 │ #0451A5 │ \\"package-1\\"
 7 │ 15,16 │ ─────── │ :
 7 │ 17,24 │ #A31515 │ \\"1.0.0\\"
 7 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  4,15 │ #0451A5 │ \\"package-2\\"
 8 │ 15,16 │ ─────── │ :
 8 │ 17,24 │ #A31515 │ \\"2.0.0\\"
 8 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  4,15 │ #0451A5 │ \\"package-3\\"
 9 │ 15,16 │ ─────── │ :
 9 │ 17,24 │ #A31515 │ \\"3.0.0\\"
 9 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  4,15 │ #0451A5 │ \\"package-4\\"
10 │ 15,16 │ ─────── │ :
10 │ 17,24 │ #A31515 │ \\"4.0.0\\"
10 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  4,15 │ #0451A5 │ \\"package-5\\"
11 │ 15,16 │ ─────── │ :
11 │ 17,24 │ #A31515 │ \\"5.0.0\\"
11 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  4,15 │ #0451A5 │ \\"package-6\\"
12 │ 15,16 │ ─────── │ :
12 │ 17,24 │ #A31515 │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  2, 3 │ ─────── │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ ─────── │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;
